==> agr-center-api-3.0.0-CLOUD-DEV-20220928.034119-44-sources.jar: com/tydic/dyc/agr/service/agr/bo/AgrItemDetailBo.java <==
package com.tydic.dyc.agr.service.agr.bo;

import lombok.Data;
import java.io.Serializable;
import com.tydic.dyc.agr.service.agr.bo.AgrItemExtBo;
import com.tydic.dyc.agr.service.agr.bo.AgrItemLadderPriceBo;
import java.math.BigDecimal;
import java.util.List;

/**
 * 描述：null 
 * 
 * @author auto_gen
 * @date 2022-09-22 13:18
 **/
@Data
public class AgrItemDetailBo implements Serializable {
	private static final long serialVersionUID =  -1715299687134186547L;

	/**
	 * 协议明细ID
	 */
	private Long agrItemId;
	/**
	 * 物料ID
	 */
	private String materialId;
	/**
	 * 物料编码
	 */
	private String materialCode;
	/**
	 * 物料名称
	 */
	private String materialName;
	/**
	 * 型号
	 */
	private String model;
	/**
	 * 图号
	 */
	private String figure;
	/**
	 * 规格
	 */
	private String spec;
	/**
	 * 材质
	 */
	private String texture;
	/**
	 * 品牌ID
	 */
	private Long brandId;
	/**
	 * 品牌
	 */
	private String brandName;
	/**
	 * 是否成品油
	 */
	private Integer whetherOil;
	/**
	 * 是否成品油转义
	 */
	private String whetherOilStr;
	/**
	 * 计量单位ID
	 */
	private Long measureId;
	/**
	 * 计量单位
	 */
	private String measureName;
	/**
	 * 数量
	 */
	private BigDecimal buyNumber;
	/**
	 * 最小起订量
	 */
	private BigDecimal moq;
	/**
	 * 采购单价
	 */
	private BigDecimal buyPrice;
	/**
	 * 采购总价
	 */
	private BigDecimal buyPriceSum;
	/**
	 * 加价比率（%）
	 */
	private BigDecimal markupRate;
	/**
	 * 原价
	 */
	private Long oldPrice;
	/**
	 * 销售单价
	 */
	private BigDecimal salePrice;
	/**
	 * 销售总价
	 */
	private BigDecimal salePriceSum;
	/**
	 * 折扣率
	 */
	private BigDecimal discountRate;
	/**
	 * 原折扣率
	 */
	private BigDecimal oldDiscountRate;
	/**
	 * 市场价
	 */
	private BigDecimal marketPrice;
	/**
	 * 协议价
	 */
	private BigDecimal agrPrice;
	/**
	 * 阶梯价组ID
	 */
	private Long ladderPriceId;
	/**
	 * 管理单位ID
	 */
	private Long managementOrgId;
	/**
	 * 供货商ID
	 */
	private Long supplierId;
	/**
	 * 供货商名称
	 */
	private String supplierName;
	/**
	 * 供货周期
	 */
	private Integer supplyCycle;
	/**
	 * 分类ID
	 */
	private String catalogId;
	/**
	 * 分类编码
	 */
	private String catalogCode;
	/**
	 * 分类名称
	 */
	private String catalogName;
	/**
	 * 税收分类编码
	 */
	private String taxCatalog;
	/**
	 * 质保等级
	 */
	private String warrantyLevel;
	/**
	 * 税率
	 */
	private BigDecimal taxRate;
	/**
	 * 商品铺货标识
	 */
	private Integer skuSymbol;
	/**
	 * 备注
	 */
	private String remark;
	/**
	 * 明细扩展
	 */
	private List<AgrItemExtBo> agrItemExt;
	/**
	 * 明细阶梯价
	 */
	private List<AgrItemLadderPriceBo> agrItemLadderPrice;
	/**
	 * 商品类型ID
	 */
	private Long commodityTypeId;
	/**
	 * 商品类型名称
	 */
	private String commodityTypeName;
	/**
	 * 排序
	 */
	private String orderBy;

}

==> agr-center-api-3.1.0-CLOUD-DEV-20230411.062329-21-sources.jar: com/tydic/dyc/agr/service/agr/bo/AgrItemDetailBo.java <==
package com.tydic.dyc.agr.service.agr.bo;

import lombok.Data;
import java.io.Serializable;
import com.tydic.dyc.agr.service.agr.bo.AgrItemExtBo;
import com.tydic.dyc.agr.service.agr.bo.AgrItemLadderPriceBo;
import java.math.BigDecimal;
import java.util.List;

/**
 * 描述：null 
 * 
 * @author auto_gen
 * @date 2023-02-08 12:03
 **/
@Data
public class AgrItemDetailBo implements Serializable {
	private static final long serialVersionUID =  5820565972804881826L;

	/**
	 * 协议明细ID
	 */
	private Long agrItemId;
	/**
	 * 物料ID
	 */
	private String materialId;
	/**
	 * 物料编码
	 */
	private String materialCode;
	/**
	 * 物料名称
	 */
	private String materialName;
	/**
	 * 型号
	 */
	private String model;
	/**
	 * 图号
	 */
	private String figure;
	/**
	 * 规格
	 */
	private String spec;
	/**
	 * 材质
	 */
	private String texture;
	/**
	 * 品牌ID
	 */
	private Long brandId;
	/**
	 * 品牌
	 */
	private String brandName;
	/**
	 * 是否成品油
	 */
	private Integer whetherOil;
	/**
	 * 是否成品油转义
	 */
	private String whetherOilStr;
	/**
	 * 计量单位ID
	 */
	private Long measureId;
	/**
	 * 计量单位
	 */
	private String measureName;
	/**
	 * 数量
	 */
	private BigDecimal buyNumber;
	/**
	 * 最小起订量
	 */
	private BigDecimal moq;
	/**
	 * 采购单价
	 */
	private BigDecimal buyPrice;
	/**
	 * 采购总价
	 */
	private BigDecimal buyPriceSum;
	/**
	 * 加价比率（%）
	 */
	private BigDecimal markupRate;
	/**
	 * 原价
	 */
	private Long oldPrice;
	/**
	 * 销售单价
	 */
	private BigDecimal salePrice;
	/**
	 * 销售总价
	 */
	private BigDecimal salePriceSum;
	/**
	 * 折扣率
	 */
	private BigDecimal discountRate;
	/**
	 * 原折扣率
	 */
	private BigDecimal oldDiscountRate;
	/**
	 * 市场价
	 */
	private BigDecimal marketPrice;
	/**
	 * 协议价
	 */
	private BigDecimal agrPrice;
	/**
	 * 阶梯价组ID
	 */
	private Long ladderPriceId;
	/**
	 * 管理单位ID
	 */
	private Long managementOrgId;
	/**
	 * 供货商ID
	 */
	private Long supplierId;
	/**
	 * 供货商名称
	 */
	private String supplierName;
	/**
	 * 供货周期
	 */
	private Integer supplyCycle;
	/**
	 * 分类ID
	 */
	private String catalogId;
	/**
	 * 分类编码
	 */
	private String catalogCode;
	/**
	 * 分类名称
	 */
	private String catalogName;
	/**
	 * 税收分类编码
	 */
	private String taxCatalog;
	/**
	 * 质保等级
	 */
	private String warrantyLevel;
	/**
	 * 税率
	 */
	private BigDecimal taxRate;
	/**
	 * 商品铺货标识
	 */
	private Integer skuSymbol;
	/**
	 * 备注
	 */
	private String remark;
	/**
	 * 明细扩展
	 */
	private List<AgrItemExtBo> agrItemExt;
	/**
	 * 明细阶梯价
	 */
	private List<AgrItemLadderPriceBo> agrItemLadderPrice;
	/**
	 * 商品类型ID
	 */
	private Long commodityTypeId;
	/**
	 * 商品类型名称
	 */
	private String commodityTypeName;
	/**
	 * 唯一键
	 */
	private String uniqueKey;
	/**
	 * 排序
	 */
	private String orderBy;

}
